@@ -57,6 +57,7 @@ def registerRestApiPaths(version: int) -> Dict[str, Union[bool, str, List[Dict[s
 
 
 def registerStatusLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[str, str]]]]:
+    
     types : List[str] = ["load"]
     descriptions : List[str] = ["Get the system load, duration can be 1,5 or 15 min"]
     if pluginInformation.cpu_is_working:
@@ -66,11 +67,6 @@ def registerStatusLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[st
             "isOptional": True,
             "description": descriptions[i],
             "parameters": [
-                {"name": "duration",
-                "description": "When this parameter is not present the raw data value(s) will be provided, otherwise the average value per second"},
-                {"name": "humanReadable",
-                "description": "For 'True' convert to better readable numbers, for 'False' return actual number. " + 
-                 "If not set to valid value, uses default value(" + str(settings.DEFAULT_TO_HUMAN_READABLE_NUMBERS) + ")."},
                 {"name": "node",
                 "description": "When this parameter is not present the average data of all nodes is presented, otherwise only from the choosen node"},
                 {"name": "token",
@@ -81,20 +77,18 @@ def registerStatusLinks(version: int) -> Dict[str, Union[bool, str, List[Dict[st
         @check_version
         @check_auth(scopes["compute_data"])
         def returnCPUStatus(version: int, datatype:str) -> Response:
-            duration = request.args.get('duration', default = -1.0, type = float)
             humanReadable = request.args.get('humanReadable', default = settings.DEFAULT_TO_HUMAN_READABLE_NUMBERS, type = settings.helpers.parse_boolean)
             logging.debug("Accessed /v%i/cpu/status/%s", version, datatype)
             
             cache_id = cache.add_cache_entry("/v" + str(version) + "/cpu/status/" + datatype)
-            cache.addParameter(cache_id, "duration", str(duration))
             
             data = CPU.plugin.getStatusData(dataType = datatype,
-                                            duration = duration,
                                             overrideHumanReadableWithValue = humanReadable)
             if len(data) > 0:
                 for data_element in data:
                     for result_name, result in data_element.items():
                         cache.addResult(cache_id, result_name, result)
+                cache.commit()
                 return make_response(jsonify(data), 200)
             
             logging.warning("Accessed /v%i/cpu/status/%s, but not avaiable", version, datatype)
